FUNCTION apex_modal_page_render (
   p_dynamic_action IN APEX_PLUGIN.T_DYNAMIC_ACTION,
   p_plugin         IN APEX_PLUGIN.T_PLUGIN 
)

   RETURN APEX_PLUGIN.T_DYNAMIC_ACTION_RENDER_RESULT
   
IS

   l_result             APEX_PLUGIN.T_DYNAMIC_ACTION_RENDER_RESULT;
   l_dialog_title       VARCHAR2(4000) := p_dynamic_action.attribute_01;
   l_url_location       VARCHAR2(50) := NVL(p_dynamic_action.attribute_02, 'STATIC');
   l_static_url         VARCHAR2(4000) := p_dynamic_action.attribute_03;
   l_attr_name          VARCHAR2(4000) := NVL(p_dynamic_action.attribute_05, 'data-url');
   l_close_sel          VARCHAR2(4000) := NVL(p_dynamic_action.attribute_06, 'div#success-message');
   l_hw_mode            VARCHAR2(4000) := NVL(p_dynamic_action.attribute_07, 'AUTO');
   l_height             VARCHAR2(4000) := p_dynamic_action.attribute_08;
   l_width              VARCHAR2(4000) := p_dynamic_action.attribute_09;
   l_modal_page_id      VARCHAR2(4000) := p_dynamic_action.attribute_10;
   l_theme              NUMBER := NVL(p_plugin.attribute_01, 3);
   l_overlay_opacity    NUMBER := NVL(TO_NUMBER(p_plugin.attribute_02, '999.99', 'NLS_NUMERIC_CHARACTERS = ''.,'''), .5);
   l_scrolling          VARCHAR2(1) := NVL(p_plugin.attribute_03, 'N');
   l_transition         VARCHAR2(50) := NVL(p_plugin.attribute_04, 'none');
   l_initial_height     NUMBER := NVL(p_plugin.attribute_05, 100);
   l_initial_width      NUMBER := NVL(p_plugin.attribute_06, 100);
   l_draggable          VARCHAR2(1) := NVL(p_plugin.attribute_07, 'Y');
   l_custom_css_path    VARCHAR2(4000) := p_plugin.attribute_08;
   l_custom_css_file    VARCHAR2(4000) := p_plugin.attribute_09;
   l_loading_image_src  VARCHAR2(32767);
   l_onload_code        VARCHAR2(32767);
   l_crlf               CHAR(2) := CHR(13)||CHR(10);

BEGIN

   IF apex_application.g_debug
   THEN
      apex_plugin_util.debug_dynamic_action(
         p_plugin         => p_plugin,
         p_dynamic_action => p_dynamic_action 
      );
   END IF;
   
   IF l_theme = 6 --User selected custom theme
   THEN
      apex_css.add_file(
         p_name      => RTRIM(RTRIM(l_custom_css_file,'.css'),'.CSS'),
         p_directory => wwv_flow.do_substitutions(l_custom_css_path),
         p_version   => NULL
      );
   ELSE 
      apex_css.add_file(
         p_name      => 't' || l_theme || 'colorbox',
         p_directory => p_plugin.file_prefix,
         p_version   => NULL
      );
   END IF;

   apex_javascript.add_library(
      p_name      => 'jquery.colorbox-min',
      p_directory => p_plugin.file_prefix,
      p_version   => NULL
   );
   
   apex_javascript.add_library(
      p_name      => 'apex_modal_page.min',
      p_directory => p_plugin.file_prefix,
      p_version   => NULL 
   );

   l_onload_code := 'apex.jQuery(document).apex_modal_page({' || l_crlf
      || '   ' || apex_javascript.add_attribute('transition',  l_transition) || l_crlf
      || '   ' || apex_javascript.add_attribute('draggable',  
         CASE l_draggable
            WHEN 'Y' THEN TRUE
            ELSE FALSE
         END
      ) || l_crlf
      || '   ' || apex_javascript.add_attribute('initialHeight',  l_initial_height) || l_crlf
      || '   ' || apex_javascript.add_attribute('initialWidth',  l_initial_width) || l_crlf
      || '   ' || apex_javascript.add_attribute('overlayOpacity',  l_overlay_opacity) || l_crlf
      || '   ' || apex_javascript.add_attribute('scrolling',  
         CASE l_scrolling
            WHEN 'Y' THEN TRUE
            ELSE FALSE
         END
      ) || l_crlf
      || '   ' || apex_javascript.add_attribute('loadingImageSrc', l_loading_image_src, FALSE, FALSE) || l_crlf
      || '});';
      
   apex_javascript.add_onload_code(
      p_code => l_onload_code
   ); 

   l_result.javascript_function := 
      'function(){' || l_crlf ||
      '   if (this.browserEvent !== ''load''){' || l_crlf ||
      '      apex.jQuery(document).apex_modal_page(''openPageFromApexThis'', this);' || l_crlf ||
      '   }' || l_crlf ||
      '}';

   l_result.attribute_01 := l_dialog_title;
   l_result.attribute_02 := l_url_location;
   l_result.attribute_03 := l_static_url;
   l_result.attribute_05 := l_attr_name;
   l_result.attribute_06 := l_close_sel;
   l_result.attribute_07 := l_hw_mode;
   l_result.attribute_08 := l_height;
   l_result.attribute_09 := l_width;
   l_result.attribute_10 := l_modal_page_id;

   RETURN l_result;
    
END apex_modal_page_render;